import React, { useState,useEffect } from "react"
import Taro from "@tarojs/taro"
import { View, Input, Picker } from "@tarojs/components"
import withLayout from '@/layouts'
import CustomNav from "@/components/CustomNav"
import MyButton from "@/components/MyButton"
import { useModel } from "@/store"
import { addBank ,getBankTypeList} from '@/services/bank'

import './style.less'


export default withLayout((props) => {
  const { person } = useModel('person')
  const [name, setName] = useState()
  const [bankCode, setBankCode] = useState()
  const [bankList,setBankList]=useState([])
  const [bankAddress, setBankAddress] = useState()
  const [phone, setPhone] = useState()
  const [loading, setLoading] = useState(false)


  const onChange = e => {
    setBankAddress(bankList[e.detail.value])
  }
  const rulePhone = (val) => {
    if (!/^1[0-9]{10}$/.test(val)) {
      Taro.showToast({
        title: '请输入正确的11位手机号',
        icon: 'none',
        duration: 2000
      })
      return false
    } else return true
  }
  const ruleCard = (val) => {
    if (!val||val.length<8) {
      Taro.showToast({
        title: '请输入正确的银行卡号',
        icon: 'none',
        duration: 2000
      })
      return false
    } else return true
  }
  const onClick = () => {
    if (name) {
      if (ruleCard(bankCode) && rulePhone(phone)) {
        setLoading(true)
        addBank({ cardNo: bankCode, personId: person.personId, ownerBank: bankAddress, owerName: name, phone: phone }).then(res => {
          Taro.showToast({
            title: '添加成功',
            icon: 'none',
            duration: 2000
          })
          setTimeout(() => {
            Taro.navigateBack({ delta: 1 })
          }, 1000)
          setLoading(false)
        }).catch(err => {
          Taro.showToast({
            title: err.message,
            icon: 'none',
            duration: 1000
          })
          setLoading(false)
        })
      }
    } else {
      Taro.showToast({
        title: '请输入持卡人姓名',
        icon: 'none',
      })
    }
  }
  useEffect(()=>{
    getBankTypeList({pageSize:500}).then((res)=>{
      setBankList(res.records.map(item=>item.name))
      setBankAddress(res.records[0].name)
    })
  },[])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='我的银行卡' />
      </View>
      <View className='index-container addBankCard'>
        <View className='title'>请绑定持卡人本人的银行卡</View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>持卡人姓名</View>：</View>
          <Input type='text' value={name} onInput={(e) => setName(e.detail.value)} placeholder='请输入真实姓名' />
        </View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>卡号</View>：
          </View>
          <Input type='number' value={bankCode} onInput={(e) => setBankCode(e.detail.value)} placeholder='请输入有效卡号' />
        </View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>开户行</View>：
          </View>
          <Picker mode='selector' style={{ width: '100%' }} range={bankList} onChange={onChange}>
            {bankAddress}
          </Picker>
        </View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>预留手机号</View>：
          </View>
          <Input type='number' maxlength='11' value={phone} onInput={(e) => setPhone(e.detail.value)} placeholder='请输入银行卡预留手机号' />
        </View>
        <View className='bottomBtn'>
          <MyButton loading={loading} value='绑定' onClick={onClick} />
        </View>
      </View>
    </View>
  )
})
