import { useState } from "react"
import Taro, { useDidShow } from "@tarojs/taro"
import { View, Image, ScrollView } from "@tarojs/components"
import withLayout from '@/layouts'
import NullCard from "@/components/NullCard";
import CustomNav from "@/components/CustomNav"
import { getBankList, deleteBank, getBankTypeList } from '@/services/bank'
import addImg from '@/assets/bank/addBank.png'
import BankCard from './Card'
import './style.less'


export default withLayout((props) => {
  const [bankList, setBankList] = useState([])

  const unBind = (val) => {
    Taro.showModal({
      content: `确认解绑?`,
      success: function (res) {
        if (res.confirm) {
          deleteBank(val).then(() => {
            Taro.showToast({
              title: '已经解除',
              icon: 'none',
            })
            getList()
          }).catch(err => {
            Taro.showToast({
              title: err.message,
              icon: 'none',
            })
          })
        }
      }
    })
  }
  const addCard = () => {
    Taro.navigateTo({ url: '/pages/addBankCard/index' });
  }
  useDidShow(() => {
    getList()
  })
  const getList = () => {
    getBankList({ pageSize: 500 }).then((res) => {
      getBankTypeList({ pageSize: 500 }).then((res2) => {
        let list1 = []
        let current
        res.records.forEach(item => {
          current = res2.records.filter(v => item.ownerBank == v.name)[0]
          list1.push({ ...item, color1: current.color1, color2: current.color2, bankCode: current.bankCode })
        });
        setBankList(list1)
      })
    })
  }
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='我的银行卡' />
      </View>
      <View className='index-container bankCardBox'>
        <ScrollView scrollY style={{ height: 'calc(100% - 89px)' }}>
          {
            bankList.length == 0 ?
              <NullCard value='您还没有添加银行卡！' /> :
              bankList.map(item => {
                return <BankCard key={item.cardId} value={item} onChange={() => unBind(item.cardId)} />
              })
          }
        </ScrollView>
        <View className='addBank' onClick={addCard}>
          <Image src={addImg} className='addIcon' />
          添加银行卡
        </View>
      </View>
    </View>
  )
})
