import Taro from "@tarojs/taro";
import { useEffect } from "react";
import { View, Image } from "@tarojs/components"
import withLayout from '@/layouts'
import CustomNav from "@/components/CustomNav";
import indexImg from "@/assets/comm/index.png";
import indexActive from "@/assets/comm/indexActive.png";
import job from "@/assets/comm/job.png";
import jobActive from "@/assets/comm/jobActive.png";
import user from "@/assets/comm/user.png";
import userActive from "@/assets/comm/userActive.png";
import { useModel } from "@/store";
import { setAmap } from '@/services/amap'
import Order from './components/Order'
import Job from './components/Job'
import User from "./components/User";
import "./index.less";



export default withLayout((props) => {
  const { router } = props
  let { tab } = router.params
  const { location, setLocation, setAddress } = useModel('location')
  const { person } = useModel('person')
  const { tpls } = useModel('tpls')
  const handleClick = (val) => {
    Taro.requestSubscribeMessage({
      tmplIds: tpls
    });

    if (!person.phone && val != 0) {
      Taro.navigateTo({ url: `/pages/Login/index?tab=${val}` })
    } else {
      Taro.redirectTo({ url: `/pages/index/index?tab=${val}` });
    }
  };
  const getAmap = (loc) => {
    setAmap({ params: 'location=' + loc, path: '/v3/geocode/regeo' }).then(res2 => {
      //josn对象取值
      setAddress(JSON.parse(res2)['regeocode'].formatted_address)
    })
  }

  useEffect(() => {
    if (!location) {
      Taro.getLocation({
        type: 'gcj02',
        success: function (res) {
          setLocation(res.longitude + ',' + res.latitude)
          getAmap(res.longitude + ',' + res.latitude)
        }
      })
    } else {
      getAmap(location)
    }
  }, [])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav home title={(!tab || tab == 0) ? '首页' : tab == 1 ? '订单列表' : '我的'} />
      </View>
      <View className='index-container'>
        {(!tab || tab == 0) && <Order />}
        {tab == 1 && <Job />}
        {tab == 2 && <User />}
      </View>
      <View className='index-tabbar'>
        <View
          className={['tabberItem', (!tab || tab == 0) ? "activeTabber" : '']}
          onClick={() => handleClick(0)}
        >
          <Image className='tabberImg' src={(!tab || tab == 0) ? indexActive : indexImg}></Image>
          <View className='text'>首页</View>
        </View>
        <View
          className={['tabberItem', tab == 1 ? "activeTabber" : '']}
          onClick={() => handleClick(1)}
        >
          <Image className='tabberImg' src={tab == 1 ? jobActive : job}></Image>
          <View className='text'>订单列表</View>
        </View>
        <View
          className={['tabberItem', tab == 2 ? "activeTabber" : '']}
          onClick={() => handleClick(2)}
        >
          <Image className='tabberImg' src={tab == 2 ? userActive : user}></Image>
          <View className='text'>个人中心</View>
        </View>
      </View>
    </View>
  );
});
