import { useEffect, useState } from "react"
import Taro, {useDidShow}from "@tarojs/taro"
import { View, ScrollView } from "@tarojs/components"
import CustomNav from "@/components/CustomNav"
import NullCard from "@/components/NullCard";
import Footer from "@/components/Footer";
import withLayout from '@/layouts'
import { useModel } from "@/store"
import { getMachineryList } from '@/services/machinery'
import MachineryCard from './Card'
import './style.less'

export default withLayout((props) => {
  const { location } = useModel('location')
  const [machinery, setMachinery] = useState([])
  const [currentPage, setCurrentPage] = useState(1)
  const [isMore, setIsMore] = useState(false)

  const goDetail = (val) => {
    Taro.navigateTo({ url: `/pages/machineryDetail/index?id=${val}` });
  }
  const goMap = (val) => {
    Taro.navigateTo({ url: `/pages/machineryMap/index?id=${val}` });
  }
   // 上拉加载
   const handleScrollToLower = () => {
    setCurrentPage(currentPage + 1)
  }
  const getList = () => {
    getMachineryList({ location: location,pageNum: currentPage }).then(res => {
      const lst = currentPage === 1 ? res.records || [] : machinery.concat(res.records || [])
      //长列表加载当下一页没有数据时
      if (res.records.length == 0 && currentPage != 1) {
        setIsMore(true)
        return
      }
      setMachinery(lst)
    })
  }
  useDidShow(() => {
    getList();
  })
  useEffect(() => {
    getList();
  }, [currentPage,location])
  
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='农机列表' />
      </View>
      <View className='index-container machineryListContent'>
        <ScrollView scrollY
          enhanced
          onScrollToLower={isMore ? '' : handleScrollToLower}
          style={{ height: '100%' }}
        >
          {
            machinery.length === 0 ? <NullCard value='您还没有农机！' /> :
              machinery?.map((item) => {
                return <MachineryCard value={item} key={item.machineryId} onClick={() => goDetail(item.machineryId)} goMap={() => goMap(item.machineryId)} />
              })
          }
          {
            machinery.length === 0 || isMore && <Footer />
          }
        </ScrollView>
      </View>
    </View>
  )
})
